@@ -1,6 +1,11 @@
-from minionize import minionizer, ProcessCallback
+import logging
 import sys
 
+from minionize import minionizer, ProcessCallback
+
+
+logging.basicConfig(level=logging.DEBUG)
+
 
 def run():
     class _Callback(ProcessCallback):
