@@ -1,17 +1,14 @@
 import logging
 from pathlib import Path
-import traceback
 import os
 
 from execo_engine.sweep import ParamSweeper
 
-from . import Callback
-
-LOGGER = logging.getLogger(__name__)
-
 from . import Engine
 from .types import Param
 
+LOGGER = logging.getLogger(__name__)
+
 ENV_PERSISTENCE_DIR = "EXECO_PERSISTENCE_DIR"
 DEFAULT_PERSISTENCE_DIR = Path("sweeps")
 
